/** BEGIN COPYRIGHT BLOCK
 * Copyright (C) 2001 Sun Microsystems, Inc.  Used by permission.
 * Copyright (C) 2005 Red Hat, Inc.
 * All rights reserved.
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation version
 * 2.1 of the License.
 *                                                                                  
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *                                                                                  
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 * END COPYRIGHT BLOCK **/
#ifndef __certmgt_h
#define __certmgt_h

#ifdef __cplusplus
extern "C" {
#endif

/*
 * Description (certmgt.h)
 *
 *	This file describes the interface to a set functions used by
 *	admin server CGI programs to manage client certificate to login
 *	name mappings.
 */

#include "cert.h"

/*
 * Description (CertMap_t)
 *
 *	This is an alternative format to the CertObj_t structure.  It
 *	contains less information, but what is there is easier to use.
 */

/*typedef struct CertMap_s CertMap_t;*/
/*struct CertMap_s {*/
/*    char * username;*/			/* login name associated with cert */
/*    char * issuercn;*/			/* issuer common name */
/*    char * subjectcn;*/			/* subject common name */
/*    USI_t certid;*/			/* cert id in database */
/*};*/

/* common flags for all types of certificates */
/* [copied from libsec/certdb.h] */
#define CERTDB_VALID_PEER	(1<<0)
#define CERTDB_TRUSTED		(1<<1)
#define CERTDB_SEND_WARN	(1<<2)
#define CERTDB_VALID_CA		(1<<3)
#define CERTDB_TRUSTED_CA	(1<<4)
#define CERTDB_NS_TRUSTED_CA	(1<<5)
#define CERTDB_USER		(1<<6)
#define CERTDB_TRUSTED_CLIENT_CA	(1<<7)

/*
 * This is the data stored in the permanent certificate database.
 * It is actually stored in the database as a stream of bytes of the
 *   following format:
 *
 *	byte offset	field
 *	-----------	-----
 *	0		sslFlags
 *	1		emailFlags
 *	2		paymentFlags
 *	3		derCert-len-msb
 *	4		derCert-len-lsb
 *	5		nickname-len-msb
 *	6		nickname-len-lsb
 *	...		derCert
 *	...		nickname
 *
 * NOTE: the nickname string as stored in the database is null terminated,
 *		in other words, the last byte of the db entry is always 0
 *		if a nickname is present.
 * NOTE: if nickname is not present, then nickname-len-msb and
 *		nickname-len-lsb will both be zero.
 */
struct _dbCert {
    PRArenaPool *arena;
    CERTCertTrust trust;
    SECItem derCert;
    char *nickname;
};

/* Flag values for cmgFilterCerts() */
#define CMGF_REVERSE	0x1		/* reverse filter */

/* Functions in certmgt.c */
PR_EXPORT(int) cmgOpenCertDB(char * alias, CERTCertDBHandle**dbhandle);
PR_EXPORT(void) cmgCloseCertDB(CERTCertDBHandle * handle);
PR_EXPORT(int) cmgShowCerts(void * handle, char * caption);
PR_EXPORT(int) cmgShowCertsBySlot(PK11SlotInfo *slot);
PR_EXPORT(int) cmgShowInternalCerts(CERTCertDBHandle *handle);
PR_EXPORT(CERTCertificate *) cmgFindCertByNickname(void * handle,
							   char *nickname);
PR_EXPORT(char *) cmgFormatName(CERTName *name);
PR_EXPORT(char *) cmgHTMLCertInfo(CERTCertificate *cert);
PR_EXPORT(CERTSignedCrl *) cmgFindCrlByName(CERTCertDBHandle *handle, char *name, int list_type);
PR_EXPORT(char *) cmgHTMLCrlInfo(CERTSignedCrl *crl);
PR_EXPORT(int) cmgShowCrls(CERTCertDBHandle *handle, int list_type);

#ifdef __cplusplus
}
#endif

#endif /* __certmgt_h */
