/** BEGIN COPYRIGHT BLOCK
 * Copyright (C) 2001 Sun Microsystems, Inc.  Used by permission.
 * Copyright (C) 2005 Red Hat, Inc.
 * All rights reserved.
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation version
 * 2.1 of the License.
 *                                                                                  
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *                                                                                  
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 * END COPYRIGHT BLOCK **/
/*
 *  Filename 
 *  --------
 *  servssl.h
 *
 *  Description
 *  -----------
 *  another try at setting up SSL uniformly
 *  
 *  Author(s)
 *  ---------
 *  Rob Walker
 *  
 *  History
 *  -------
 *  Wed Apr  7 00:45:16 1999 - Created
 *
 */
#ifndef SSLPSET_H
#define SSLPSET_H

#ifdef __cplusplus
extern "C" {
#endif /* #ifdef __cplusplus */
/**
  || Function
  || --------
  || void SVRCORE_SSLInitPset(PsetHndl pset, const char *pset_prefix,
  ||    char *pszServerRoot,
  ||    const char **ppszCertNames,
  ||    const char *pszSessionIDCacheDir,
  ||    int nSessionIDCacheSize,
  ||    SVRCOREPinObj *pin,
  ||    SVRCORE_WarnFn fnWarn, void *pCx,
  ||    CERTCertificate **apcc,
  ||    SECKEYPrivateKey **apsk,
  ||    PRFileDesc **ppprfd);
  ||  
  || Description
  || -----------
  || initializes SSL to a PRFileDesc that may be used as a model for
  ||    future calls SSL_ImportFD()
  ||
  || Parameters
  || ----------
  || PSetHndl pset: Pset handle for reading configuration
  || const char *pset_prefix: Pset attribute prefix (e.g. "encryption")
  || char *pszServerRoot: path to the server root
  || const char **ppszCertNames: optional array of token:certificate names
  ||                       If NULL, uses the token/cert names in the pset
  || const char *pszSessionIDCacheDir: directory where the session cache will reside
  ||                              if NULL, the SIDCache is not initialized
  || int   nSessionIDCacheSize: size (default of 0 makes a reasonable guess)
  || SVRCOREPinObj *pin: pin object for unlocking PKCS11 tokens
  ||                       SVRCORE is responsible for deleting the object
  || SVRCORE_WarnFn fnWarn, void *pCx: logging callback and context
  ||                       (MakeModel does a lot, wants to report)
  ||                         may be NULL
  || CERTCertificate **apcc: in/out array of pointers to certificates
  ||                           if non-NULL, must be the same size as 
  ||                           pszCertNickNames, may be NULL, 
  ||                           if you don't want the list
  || SECKEYPrivateKey **apsk: in/out array of pointers to keys
  ||                            if non-NULL, must be the same size as 
  ||                            pszCertNickNames, may be NULL, if you don't 
  ||                            want the list
  ||                            1:1 correspondence with apcc
  || PRFileDesc **ppprfd: out pointer to PRFileDesc *, set to NULL on failure,
  ||			    should be closed with PR_Close()
  ||
  || Returns
  || -------
  || -1 on failure.  If *pprfd is non-NULL, model is good for client-side
  ||    SSL, but does not have server-side correctly initialized
  || 0 on success
  ||
  || Remarks
  || -------
  || PR_SetError() may be called by underlying NSS code
  || 
  || The PRFileDesc created (if created) must be closed with PR_Close()
  ||   no other methods on the model are implemented.  It may only be used
  ||   as the argument to PR_Close() or the first argument of SSL_ImportFD().
  ||
  || Turns on SSL_SECURITY and SSL_ENABLE_SSL3.  Turns off SSL_ENABLE_SSL2 and
  ||   SSL_REQUIRE_CERTIFICATE.  Turns on SSL_REQUEST_CERTIFICATE if and only
  ||   if the certificate database contains at least one CA trusted for 
  ||   client certs.  Caller may subsequently change these as necessary.
  ||
  */
int SVRCORE_SSLInitPset(void *pset, const char *pset_prefix,
    const char *pszServerRoot,
    const char **ppszCertNames,
    const char *pszSessionIDCacheDir,
    int nSessionIDCacheSize,
    SVRCOREPinObj *pin,
    SVRCORE_WarnFn fnWarn, void *pCx,
    CERTCertificate **apcc,
    SECKEYPrivateKey **apsk,
    PRFileDesc **ppprfd);
#ifdef __cplusplus
}
#endif /* #ifdef __cplusplus */

#endif /* #ifndef SERVSSL_H */
