/** BEGIN COPYRIGHT BLOCK
 * Copyright (C) 2001 Sun Microsystems, Inc.  Used by permission.
 * Copyright (C) 2005 Red Hat, Inc.
 * All rights reserved.
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation version
 * 2.1 of the License.
 *                                                                                  
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *                                                                                  
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 * END COPYRIGHT BLOCK **/
/*
 * form_post.c - Functions to help with handling POSTs
 *
 * All blame to Mike McCool
 */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "libadminutil/admutil.h"
#include "dbtadmutil.h"

extern Resource *admutil_i18nResource;
extern char *admutil_acceptLang;

#ifndef BIG_LINE
#define BIG_LINE 1024
#endif

#if 0
#define SUCCESS_HTML "success.html"
#endif

static char **input;

#ifdef XP_WIN32
PR_IMPLEMENT(char *)
Get_QueryNT(void)
{
    char *qs = getenv("QUERY_STRING");
    if(qs && (*qs == '\0'))
        qs = NULL;
    return qs;
}
#endif  /* XP_WIN32 */
 
PR_IMPLEMENT(char **)
get_input_ptr(void)
{
    return input;
}

PR_IMPLEMENT(void)
form_unescape(char *str) 
{
    register int x = 0, y = 0;
    int l = PL_strlen(str);
    char digit;

    while(x < l)  {
        if((str[x] == '%') && (x < (l - 2)))  {
            ++x;
            digit = (str[x] >= 'A' ? 
                         ((str[x] & 0xdf) - 'A')+10 : (str[x] - '0'));
            digit *= 16;

            ++x;
            digit += (str[x] >= 'A' ? 
                         ((str[x] & 0xdf) - 'A')+10 : (str[x] - '0'));

            str[y] = digit;
        } 
        else if(str[x] == '+')  {
            str[y] = ' ';
        } else {
            str[y] = str[x];
        }
        x++;
        y++;
    }
    str[y] = '\0';
}

PR_IMPLEMENT(void)
post_begin(FILE *in) 
{
    char *vars = NULL, *tmp = NULL;
    int cl;

    if(!(tmp = getenv("CONTENT_LENGTH"))) {
      if (admutil_i18nResource) {
    rpt_err(INCORRECT_USAGE,
        (char*)res_getstring(admutil_i18nResource,
                  DBT_formPost_Browser_err,
                  admutil_acceptLang),
        (char*)res_getstring(admutil_i18nResource,
                  DBT_formPost_Browser_errDetail,
                  admutil_acceptLang),
        NULL);
      }
      else {
        rpt_err(INCORRECT_USAGE, 
        "Browser Error", 
        "Your browser sent no content length with a POST command. Please be sure to use a fully compliant browser.",
        NULL);
      }
    }
        
    cl = atoi(tmp);

    vars = (char *)PR_Malloc(cl+1);

    if( !(fread(vars, 1, cl, in)) ) {
      if (admutil_i18nResource) {
          rpt_err(SYSTEM_ERROR,
                  NULL,
                  (char*)res_getstring(admutil_i18nResource,
                                       DBT_formPost_PostStdinErr,
                                       admutil_acceptLang),
                  NULL);
      }
      else {
        rpt_err(SYSTEM_ERROR,
                NULL, 
                "The POST variables could not be read from stdin.",
                NULL);
      }
    }

    vars[cl] = '\0';

    input = string_to_vec(vars);
}

PR_IMPLEMENT(void)
get_begin(char *qs)
{
    input = string_to_vec(qs);
}

PR_IMPLEMENT(char **)
string_to_vec(char *in)
{
    char **ans;
    int vars = 0;
    register int x = 0;
    char *tmp;

    in = PL_strdup(in);

    while(in[x])
        if(in[x++]=='=')
            vars++;
    
    ans = new_strlist(vars+1);
  
    x=0;
    tmp = strtok(in, "&");
    if (!tmp) { /* error, bail out */
        PR_Free(in);
        return(ans);
    }
    ans[x]=PL_strdup(tmp);
    form_unescape(ans[x++]);

    while((tmp = strtok(NULL, "&")))  {
        ans[x] = PL_strdup(tmp);
        form_unescape(ans[x++]);
    }

    PR_Free(in);

    return(ans);
}

PR_IMPLEMENT(char *)
get_cgi_var(char *varname, char *elem_id, char *bongmsg)
{
    register int x = 0;
    int len = PL_strlen(varname);
    char *ans = NULL;
   
    while(input[x])  {
    /*  We want to get rid of the =, so len, len+1 */
        if((!strncmp(input[x], varname, len)) && (*(input[x]+len) == '='))  {
            ans = PL_strdup(input[x] + len + 1);
            if(!strcmp(ans, ""))
                ans = NULL;
            break;
        }  else
            x++;
    }
    if(ans == NULL)  {
        if ((bongmsg) && PL_strlen(bongmsg))
            rpt_err(ELEM_MISSING, elem_id, bongmsg, NULL);
        else
            return NULL;
    }
    else
        return(ans);
    /* shut up gcc */
    return NULL;
}

PR_IMPLEMENT(long)
get_cgi_long(char *varname)
{
    char *ans = get_cgi_var(varname, NULL, NULL);
 
    return ans ? atol(ans) : -1L;
}

PR_IMPLEMENT(int)
get_cgi_int(char *varname)
{
    return (int)get_cgi_long(varname);
}

PR_IMPLEMENT(int)
get_cgi_bool(char *varname)
{
    char *ans = get_cgi_var(varname, NULL, NULL);
 
    return (ans && *ans && (*ans - '0')) ? 1 : 0;
}

PR_IMPLEMENT(char **)
get_cgi_multiple(char *varname, char *elem_id, char *bongmsg)
{
    register int n, x;
    int len = PL_strlen(varname);
    char **ans = NULL;

    for(n=0; input[n]; n++);
    ans = new_strlist(n + 1);

    for(x=n=0; input[x]; x++)  {
        if ((!strncmp(input[x], varname, len)) &&
        (*(input[x]+len) == '=') &&
        (*(input[x]+len+1))) {
            ans[n] = PL_strdup(input[x] + len + 1);
        n++;
        }
    }
    ans[n] = NULL;

    if (!n)  {
        PR_Free(ans);
        if(bongmsg)
            rpt_err(ELEM_MISSING, elem_id, bongmsg, NULL);
        else
            return NULL;
    }
    else {
        return ans;
    }
    /* shut up gcc */
    return NULL;
}

#if 0
/* Removed since front end is JAVA, no need to send html page back! */
PR_IMPLEMENT(void)
return_success(char *description)
{
    char **config=get_adm_config();
    WSACleanup();

    fprintf(stdout, "\n<SCRIPT language=%s>", MOCHA_NAME);
#ifdef MCC_HTTPD /* template->style usability */
    /* If we're working with styles, jump directly back to the edit style
     * page. */
    if(!strcmp(get_current_typestr(config), TEMPLATE) ||
       ((get_current_restype(config)==PB_NAME) && 
        (strcmp(get_current_resource(config), "default"))))  {
        fprintf(stdout, "top.%s.%s.location='%s';", 
                BOTTOM_NAME, CONTENT_NAME, "index/tmpled");
        fprintf(stdout, "</SCRIPT>\n");
    }  else
#endif
    fprintf(stdout, "alert('Success!\\n%s');", 
                    alert_word_wrap(description, WORD_WRAP_WIDTH, "\\n"));
    fprintf(stdout, "</SCRIPT>\n");
    js_open_referer();
#ifdef NS_MAIL
    char line[BIG_LINE];
    char **config = get_adm_config();
    FILE *html=open_html_file(SUCCESS_HTML);

    WSACleanup();

    /* Be sure headers are terminated. */
    fputs("\n", stdout);

    while(next_html_line(html, line))  {
        if(parse_line(line, config))  {
            if(directive_is(line, "SUCCESS_DESCRIPTION"))  {
                fprintf(stdout, "<dl><dt><FONT size=+1>Success!</FONT>\n");
                fprintf(stdout, "<dd>%s\n</dl>", description);
            }
        }
    }
#endif /* NS_MAIL */
    exit(0);
}
#endif  /* 0 */



PR_IMPLEMENT(void)
rm_trail_slash(char *target)
{
    int l;
    
    if(!target) return;

    l = PL_strlen(target) - 1;

    if((target[l] == '/') && (l != 0))
        target[l] = '\0';
}

/* Compresses spaces only. */
PR_IMPLEMENT(void)
compress_spaces(char *source) 
{
    register int x, y;

    if(!source) return;

    for(x=0, y=0; source[x]; x++)  {
        if(source[x] != ' ')
             source[y++] = source[x];
    }
    source[y] = '\0';
}

/* Compresses spaces and replaces commas with an or list */
PR_IMPLEMENT(char *)
compress_and_replace(char *source) 
{
    char *answer;
    int hascomma, x, y;

    if(!source) return source;

    hascomma = (strchr(source, ',')) ? 1 : 0;

    /* + 2 = 1 for trailing \0 and one put in by Aruna for NT */
    answer = (char *)PR_Malloc(PL_strlen(source) + 2);
    if (NULL == answer)
        return NULL;

    for(x=0, y=0; source[x]; x++)  {
        if(source[x] == ',')
             answer[y++] = '|';
        else if(source[x] != ' ')
             answer[y++] = source[x];
        answer[y] = '\0';
    }
    if(!hascomma)
        return(answer);
    else {
        char *newanswer = PR_smprintf("(%s)", answer);
        free_str(answer);
        return(newanswer);
    }
}

