#
# BEGIN COPYRIGHT BLOCK
# Copyright (C) 2001 Sun Microsystems, Inc.  Used by permission.
# Copyright (C) 2005 Red Hat, Inc.
# All rights reserved.
# 
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation version
# 2.1 of the License.
#                                                                                  
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#                                                                                  
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
# END COPYRIGHT BLOCK
#
#
# Makefile to Create Admin Util packages
#

BUILD_ROOT:=.
include $(BUILD_ROOT)/nsdefs.mk
include $(BUILD_ROOT)/nsconfig.mk

MKDIR=mkdir -p

# Destination directories for package
PKGDIR_NAME=$(FULL_RTL_OBJDIR)
PKGTOP=$(ABS_ROOT)/built/adminutil/$(PKGDIR_NAME)
PKGDIR=$(PKGTOP)

ifdef BUILD_INTL
PKGDIR_NAME+=-intl
PKGTOP=$(ABS_ROOT)/built/adminutil/$(PKGDIR_NAME)
PKGDIR=$(PKGTOP)
endif

ifndef INSTDIR
    MMDD := $(shell date +%m.%d)
    INSTDIR := $(ABS_ROOT)/../$(MMDD)
    PKGINSTDIR := $(ABS_ROOT)/../$(MMDD)/$(PKGDIR_NAME)
endif
ABS_INSTDIR := $(shell if test \! -f $(INSTDIR); then mkdir $(INSTDIR); fi; cd $(INSTDIR); pwd)
ABS_PKGINSTDIR := $(shell if test \! -f $(PKGINSTDIR); then mkdir $(PKGINSTDIR); fi; cd $(PKGINSTDIR); pwd)

# set the values of the macros used by rpmbuild
# name and version of RPM - must correspond to the spec file - these get branded
RPM_BASE_NAME=fedora
RPM_VERSION=1.0
RPM_FILE_BASE=$(RPM_BASE_NAME)-adminutil-devel-$(RPM_VERSION)
RPM_ARCH = $(shell uname -i)
# root dir for RPM built and temp files
ABS_TOPDIR = $(ABS_INSTDIR)
RPM_TOPDIR = --define "_topdir $(ABS_TOPDIR)"
# location of source tarball
RPM_SOURCEDIR = --define "_sourcedir $(ABS_TOPDIR)"
# location of staging area built into RPM
RPM_BUILDDIR = --define "_builddir $(ABS_PKGINSTDIR)"
# location of final RPM file
RPM_RPMDIR = --define "_rpmdir $(ABS_TOPDIR)"
# location of source RPM
RPM_SRPMDIR = --define "_srcrpmdir $(ABS_TOPDIR)"
ifneq ($(BUILD_DEBUG), optimize)
	RPM_FLAVOR = dbg
else
	RPM_FLAVOR = opt
endif

all: pkguxAdminUtil pkgSBC pkgRPM

pkguxAdminUtil:

	rm -rf $(PKGDIR)
	-$(MKDIR) $(PKGDIR)
	-$(MKDIR) $(PKGDIR)/include
	-$(MKDIR) $(PKGDIR)/include/libadminutil
	-$(MKDIR) $(PKGDIR)/include/libadmsslutil
	-$(MKDIR) $(PKGDIR)/lib
	-$(MKDIR) $(PKGDIR)/lib/property

	cp -p $(ABS_ROOT)/include/libadminutil/*.h $(PKGDIR)/include/libadminutil
	cp -p $(ABS_ROOT)/include/libadmsslutil/*.h $(PKGDIR)/include/libadmsslutil
# Don't package sslpset.h
	rm -f $(PKGDIR)/include/libadmsslutil/sslpset.h
	cp -p $(ADMSERV_OBJDIR)/lib/*.* $(PKGDIR)/lib
	cp -p $(ADMSERV_OBJDIR)/lib/libadminutil/lib*.res  $(PKGDIR)/lib/property

pkgSBC:
	-$(RM) -rf $(ABS_PKGINSTDIR)
	-$(MKDIR) $(ABS_PKGINSTDIR)
	cp -r $(PKGDIR)/lib $(ABS_PKGINSTDIR)
	cp -r $(PKGDIR)/include $(ABS_PKGINSTDIR)
	cd $(ABS_PKGINSTDIR); tar -cvf - * | gzip -c > adminutil.tar.gz
# create a source tar ball (ABS_INSTDIR is always new and clean)
ifneq ($(ARCH), WINNT)
	cd $(ABS_INSTDIR); ln -s $(ABS_ROOT) $(RPM_FILE_BASE); \
	tar cfh - --exclude \*/built --exclude \*/CVS $(RPM_FILE_BASE) --exclude \*/branding --exclude \*/RHEL* --exclude \*/SunOS* --exclude \*/HP* --exclude \*/Linux* | gzip > $(RPM_FILE_BASE).tar.gz; \
	rm -rf $(RPM_FILE_BASE)
endif

pkgRPM: 
ifdef BUILD_RPM
# make a spec file (it's moved to OBJDIR)
	$(MAKE) -C $(ABS_ROOT) $(RPM_BASE_NAME)-adminutil.spec
	rpmbuild $(RPM_TOPDIR) $(RPM_SOURCEDIR) $(RPM_BUILDDIR) $(RPM_RPMDIR) $(RPM_SRPMDIR) --define "flavor $(RPM_FLAVOR)" --clean --nodeps -ba $(OBJDIR)/$(RPM_BASE_NAME)-adminutil.spec
	cd $(ABS_INSTDIR); rm -f $(RPM_FILE_BASE).tar.gz
endif # BUILD_RPM
